Index: FCKeditor/trunk/editor/filemanager/connectors/asp/config.asp
===================================================================
--- FCKeditor/trunk/editor/filemanager/connectors/asp/config.asp	(revision 1040)
+++ FCKeditor/trunk/editor/filemanager/connectors/asp/config.asp	(revision 1041)
@@ -23,5 +23,5 @@
 <%
 
-' SECURITY: You must explicitelly enable this "connector" (set it to "True").
+' SECURITY: You must explicitly enable this "connector" (set it to "True").
 ' WARNING: don't just set "ConfigIsEnabled = true", you must be sure that only 
 '		authenticated users can access this file or use some kind of session checking.
@@ -35,5 +35,5 @@
 ConfigUserFilesPath = "/userfiles/"
 
-' Due to security issues with Apache modules, it is reccomended to leave the
+' Due to security issues with Apache modules, it is recommended to leave the
 ' following setting enabled.
 Dim ConfigForceSingleExtension
@@ -61,5 +61,5 @@
 '		If it is empty then no restrictions are done here.
 '
-'	For a file to be uploaded it has to fullfil both the AllowedExtensions
+'	For a file to be uploaded it has to fulfill both the AllowedExtensions
 '	and DeniedExtensions (that's it: not being denied) conditions.
 '
@@ -71,5 +71,5 @@
 '		an absolute path. 
 '		If it's an empty string then it will be autocalculated.
-'		Usefull if you are using a virtual directory, symbolic link or alias. 
+'		Useful if you are using a virtual directory, symbolic link or alias. 
 '		Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 '		Attention: The above 'FileTypesPath' must point to the same directory.
@@ -84,5 +84,5 @@
 '		an absolute path. 
 '		If it's an empty string then it will be autocalculated.
-'		Usefull if you are using a virtual directory, symbolic link or alias. 
+'		Useful if you are using a virtual directory, symbolic link or alias. 
 '		Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 '		Attention: The above 'QuickUploadPath' must point to the same directory.
@@ -105,5 +105,5 @@
 ConfigQuickUploadAbsolutePath.Add "File", ""
 
-ConfigAllowedExtensions.Add	"Image", "bmp|gif|jpeg|jpg|png|psd|tif|tiff"
+ConfigAllowedExtensions.Add	"Image", "bmp|gif|jpeg|jpg|png"
 ConfigDeniedExtensions.Add	"Image", ""
 ConfigFileTypesPath.Add "Image", ConfigUserFilesPath & "image/"
@@ -112,5 +112,5 @@
 ConfigQuickUploadAbsolutePath.Add "Image", ""
 
-ConfigAllowedExtensions.Add	"Flash", "swf|fla"
+ConfigAllowedExtensions.Add	"Flash", "swf|flv"
 ConfigDeniedExtensions.Add	"Flash", ""
 ConfigFileTypesPath.Add "Flash", ConfigUserFilesPath & "flash/"
Index: FCKeditor/trunk/editor/filemanager/connectors/cfm/config.cfm
===================================================================
--- FCKeditor/trunk/editor/filemanager/connectors/cfm/config.cfm	(revision 1040)
+++ FCKeditor/trunk/editor/filemanager/connectors/cfm/config.cfm	(revision 1041)
@@ -38,5 +38,5 @@
 	Config.ServerPath = "" ;
 
-	// Due to security issues with Apache modules, it is reccomended to leave the
+	// Due to security issues with Apache modules, it is recommended to leave the
 	// following setting enabled.
 	Config.ForceSingleExtension = true ;
@@ -65,5 +65,5 @@
 //		If it is empty then no restrictions are done here.
 //
-//	For a file to be uploaded it has to fullfil both the AllowedExtensions
+//	For a file to be uploaded it has to fulfill both the AllowedExtensions
 //	and DeniedExtensions (that's it: not being denied) conditions.
 //
@@ -108,5 +108,5 @@
 	Config.QuickUploadAbsolutePath["File"] 	= Config.FileTypesAbsolutePath["File"] ;
 
-	Config.AllowedExtensions["Image"] 		= "bmp,gif,jpeg,jpg,png,psd,tif,tiff" ;
+	Config.AllowedExtensions["Image"] 		= "bmp,gif,jpeg,jpg,png" ;
 	Config.DeniedExtensions["Image"] 		= "" ;
 	Config.FileTypesPath["Image"] 			= Config.UserFilesPath & 'image/' ;
@@ -115,5 +115,5 @@
 	Config.QuickUploadAbsolutePath["Image"] = Config.FileTypesAbsolutePath["Image"] ;
 
-	Config.AllowedExtensions["Flash"] 		= "swf,fla" ;
+	Config.AllowedExtensions["Flash"] 		= "swf,flv" ;
 	Config.DeniedExtensions["Flash"] 		= "" ;
 	Config.FileTypesPath["Flash"] 			= Config.UserFilesPath & 'flash/' ;
Index: FCKeditor/trunk/editor/filemanager/connectors/lasso/config.lasso
===================================================================
--- FCKeditor/trunk/editor/filemanager/connectors/lasso/config.lasso	(revision 1040)
+++ FCKeditor/trunk/editor/filemanager/connectors/lasso/config.lasso	(revision 1041)
@@ -52,6 +52,6 @@
 		'AllowedExtensions' = map(
 			'File' = array('7z','aiff','asf','avi','bmp','csv','doc','fla','flv','gif','gz','gzip','jpeg','jpg','mid','mov','mp3','mp4','mpc','mpeg','mpg','ods','odt','pdf','png','ppt','pxd','qt','ram','rar','rm','rmi','rmvb','rtf','sdc','sitd','swf','sxc','sxw','tar','tgz','tif','tiff','txt','vsd','wav','wma','wmv','xls','xml','zip'),
-			'Image' = array('bmp','gif','jpeg','jpg','png','psd','tif','tiff'),
-			'Flash' = array('swf','fla'),
+			'Image' = array('bmp','gif','jpeg','jpg','png'),
+			'Flash' = array('swf','flv'),
 			'Media' = array('aiff','asf','avi','bmp','fla','flv','gif','jpeg','jpg','mid','mov','mp3','mp4','mpc','mpeg','mpg','png','qt','ram','rm','rmi','rmvb','swf','tif','tiff','wav','wma','wmv')
 		),
Index: FCKeditor/trunk/editor/filemanager/connectors/py/config.py
===================================================================
--- FCKeditor/trunk/editor/filemanager/connectors/py/config.py	(revision 1040)
+++ FCKeditor/trunk/editor/filemanager/connectors/py/config.py	(revision 1041)
@@ -23,5 +23,5 @@
 """
 
-# INSTALLATION NOTE: You must set up your server enviroment accordingly to run 
+# INSTALLATION NOTE: You must set up your server environment accordingly to run 
 # python scripts. This connector requires Python 2.4 or greater.
 # 
@@ -29,5 +29,5 @@
 #  * WSGI (recommended): You'll need apache + mod_python + modpython_gateway 
 #                        or any web server capable of the WSGI python standard
-#  * Plain Old CGI:      Any server capable of running standartd python scripts
+#  * Plain Old CGI:      Any server capable of running standard python scripts
 #                        (although mod_python is recommended for performance)
 #                        This was the previous connector version operation mode
@@ -40,5 +40,5 @@
 
    
-# SECURITY: You must explicitelly enable this "connector". (Set it to "True").
+# SECURITY: You must explicitly enable this "connector". (Set it to "True").
 # WARNING: don't just set "ConfigIsEnabled = True", you must be sure that only 
 #		authenticated users can access this file or use some kind of session checking.
@@ -49,5 +49,5 @@
 
 # Fill the following value it you prefer to specify the absolute path for the
-# user files directory. Usefull if you are using a virtual directory, symbolic
+# user files directory. Useful if you are using a virtual directory, symbolic
 # link or alias. Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 # Attention: The above 'UserFilesPath' must point to the same directory.
@@ -56,5 +56,5 @@
 UserFilesAbsolutePath = '' 
 
-# Due to security issues with Apache modules, it is reccomended to leave the
+# Due to security issues with Apache modules, it is recommended to leave the
 # following setting enabled.
 ForceSingleExtension = True 
@@ -78,5 +78,5 @@
 #		If it is empty then no restrictions are done here.
 #
-#	For a file to be uploaded it has to fullfil both the AllowedExtensions
+#	For a file to be uploaded it has to fulfill both the AllowedExtensions
 #	and DeniedExtensions (that's it: not being denied) conditions.
 #
@@ -88,5 +88,5 @@
 #		an absolute path. 
 #		If it's an empty string then it will be autocalculated.
-#		Usefull if you are using a virtual directory, symbolic link or alias. 
+#		Useful if you are using a virtual directory, symbolic link or alias. 
 #		Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 #		Attention: The above 'FileTypesPath' must point to the same directory.
@@ -102,5 +102,5 @@
 #		an absolute path. 
 #		If it's an empty string then it will be autocalculated.
-#		Usefull if you are using a virtual directory, symbolic link or alias. 
+#		Useful if you are using a virtual directory, symbolic link or alias. 
 #		Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 #		Attention: The above 'QuickUploadPath' must point to the same directory.
@@ -114,5 +114,5 @@
 QuickUploadAbsolutePath['File']	= FileTypesAbsolutePath['File']
 
-AllowedExtensions['Image']		= ['bmp','gif','jpeg','jpg','png','psd','tif','tiff']
+AllowedExtensions['Image']		= ['bmp','gif','jpeg','jpg','png']
 DeniedExtensions['Image']		= []
 FileTypesPath['Image']			= UserFilesPath + 'image/' 
@@ -121,5 +121,5 @@
 QuickUploadAbsolutePath['Image']= FileTypesAbsolutePath['Image']
 
-AllowedExtensions['Flash']		= ['swf','fla']
+AllowedExtensions['Flash']		= ['swf','flv']
 DeniedExtensions['Flash']		= []
 FileTypesPath['Flash']			= UserFilesPath + 'flash/'
Index: FCKeditor/trunk/fckconfig.js
===================================================================
--- FCKeditor/trunk/fckconfig.js	(revision 1040)
+++ FCKeditor/trunk/fckconfig.js	(revision 1041)
@@ -286,6 +286,6 @@
 FCKConfig.LinkUpload = true ;
 FCKConfig.LinkUploadURL = FCKConfig.BasePath + 'filemanager/connectors/' + _QuickUploadLanguage + '/upload.' + _QuickUploadLanguage ;
-FCKConfig.LinkUploadAllowedExtensions	= "" ;			// empty for all
-FCKConfig.LinkUploadDeniedExtensions	= ".(html|htm|php|php2|php3|php4|php5|phtml|pwml|inc|asp|aspx|ascx|jsp|cfm|cfc|pl|bat|exe|com|dll|vbs|js|reg|cgi|htaccess|asis|sh|shtml|shtm|phtm)$" ;	// empty for no one
+FCKConfig.LinkUploadAllowedExtensions	= ".(7z|aiff|asf|avi|bmp|csv|doc|fla|flv|gif|gz|gzip|jpeg|jpg|mid|mov|mp3|mp4|mpc|mpeg|mpg|ods|odt|pdf|png|ppt|pxd|qt|ram|rar|rm|rmi|rmvb|rtf|sdc|sitd|swf|sxc|sxw|tar|tgz|tif|tiff|txt|vsd|wav|wma|wmv|xls|xml|zip)$" ;			// empty for all
+FCKConfig.LinkUploadDeniedExtensions	= "" ;	// empty for no one
 
 FCKConfig.ImageUpload = true ;
@@ -296,5 +296,5 @@
 FCKConfig.FlashUpload = true ;
 FCKConfig.FlashUploadURL = FCKConfig.BasePath + 'filemanager/connectors/' + _QuickUploadLanguage + '/upload.' + _QuickUploadLanguage + '?Type=Flash' ;
-FCKConfig.FlashUploadAllowedExtensions	= ".(swf|fla)$" ;		// empty for all
+FCKConfig.FlashUploadAllowedExtensions	= ".(swf|flv)$" ;		// empty for all
 FCKConfig.FlashUploadDeniedExtensions	= "" ;					// empty for no one
 

Index: FCKeditor/trunk/editor/filemanager/connectors/php/config.php
===================================================================
--- FCKeditor/trunk/editor/filemanager/connectors/php/config.php	(revision 1040)
+++ FCKeditor/trunk/editor/filemanager/connectors/php/config.php	(revision 1041)
@@ -25,5 +25,5 @@
 global $Config ;
 
-// SECURITY: You must explicitelly enable this "connector". (Set it to "true").
+// SECURITY: You must explicitly enable this "connector". (Set it to "true").
 // WARNING: don't just set "ConfigIsEnabled = true", you must be sure that only 
 //		authenticated users can access this file or use some kind of session checking.
@@ -39,10 +39,10 @@
 
 // Fill the following value it you prefer to specify the absolute path for the
 // user files directory. Usefull if you are using a virtual directory, symbolic
 // link or alias. Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 // Attention: The above 'UserFilesPath' must point to the same directory.
 $Config['UserFilesAbsolutePath'] = '' ;
 
-// Due to security issues with Apache modules, it is reccomended to leave the
+// Due to security issues with Apache modules, it is recommended to leave the
 // following setting enabled.
 $Config['ForceSingleExtension'] = true ;
@@ -70,5 +70,5 @@
 		If it is empty then no restrictions are done here.
 
-	For a file to be uploaded it has to fullfil both the AllowedExtensions
+	For a file to be uploaded it has to fulfill both the AllowedExtensions
 	and DeniedExtensions (that's it: not being denied) conditions.
 
@@ -80,5 +80,5 @@
 		an absolute path. 
 		If it's an empty string then it will be autocalculated.
-		Usefull if you are using a virtual directory, symbolic link or alias. 
+		Useful if you are using a virtual directory, symbolic link or alias. 
 		Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 		Attention: The above 'FileTypesPath' must point to the same directory.
@@ -93,5 +93,5 @@
 		an absolute path. 
 		If it's an empty string then it will be autocalculated.
-		Usefull if you are using a virtual directory, symbolic link or alias. 
+		Useful if you are using a virtual directory, symbolic link or alias. 
 		Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 		Attention: The above 'QuickUploadPath' must point to the same directory.
@@ -101,5 +101,5 @@
 	 	"userfiles" directory to maintain backwards compatibility with older versions of FCKeditor. 
 	 	This is fine, but you in some cases you will be not able to browse uploaded files using file browser.
-	 	Example: if you clik on "image button", select "Upload" tab and send image 
+	 	Example: if you click on "image button", select "Upload" tab and send image 
 	 	to the server, image will appear in FCKeditor correctly, but because it is placed 
 	 	directly in /userfiles/ directory, you'll be not able to see it in built-in file browser.
@@ -121,5 +121,5 @@
 $Config['QuickUploadAbsolutePath']['File']= $Config['UserFilesAbsolutePath'] ;
 
-$Config['AllowedExtensions']['Image']	= array('bmp','gif','jpeg','jpg','png','psd','tif','tiff') ;
+$Config['AllowedExtensions']['Image']	= array('bmp','gif','jpeg','jpg','png') ;
 $Config['DeniedExtensions']['Image']	= array() ;
 $Config['FileTypesPath']['Image']		= $Config['UserFilesPath'] . 'image/' ;
@@ -128,5 +128,5 @@
 $Config['QuickUploadAbsolutePath']['Image']= $Config['UserFilesAbsolutePath'] ;
 
-$Config['AllowedExtensions']['Flash']	= array('swf','fla') ;
+$Config['AllowedExtensions']['Flash']	= array('swf','flv') ;
 $Config['DeniedExtensions']['Flash']	= array() ;
 $Config['FileTypesPath']['Flash']		= $Config['UserFilesPath'] . 'flash/' ;
@@ -39,10 +39,10 @@
 
 // Fill the following value it you prefer to specify the absolute path for the
-// user files directory. Usefull if you are using a virtual directory, symbolic
+// user files directory. Useful if you are using a virtual directory, symbolic
 // link or alias. Examples: 'C:\\MySite\\userfiles\\' or '/root/mysite/userfiles/'.
 // Attention: The above 'UserFilesPath' must point to the same directory.